@@ -1,25 +1,26 @@
-#' @title custom function for getting specified number of decimal places in results for p-value
+#'
+#' @title Custom function for getting specified number of decimal places in
+#'   results for p-value
 #' @name specify_decimal_p
 #' @aliases specify_decimal_p
-#' @description Function to format an R object for pretty printing with a specified number of decimal places. The
-#' function also allows highly significant p-values to be denoted as "p < 0.001" rather than "p = 0.000".
+#' @description Function to format an R object for pretty printing with a
+#'   specified (`k`) number of decimal places. The function also allows highly
+#'   significant p-values to be denoted as "p < 0.001" rather than "p = 0.000".
 #' @author Indrajeet Patil
 #'
 #' @param x A numeric variable.
-#' @param k Number of digits after decimal point (should be an integer).
+#' @param k Number of digits after decimal point (should be an integer) (Default: `k = 3`).
 #' @param p.value Decides whether the number is a p-value (Dafault: `FALSE`).
 #'
-#' @return formatted p-values from statistical tests
+#' @return Formatted numeric values.
 #'
 #' @export
+#'
 
 specify_decimal_p <- function(x,
-                              k = NULL,
+                              k = 3,
                               p.value = FALSE) {
-  # if the number of decimal places hasn't been specified, use the default of 3
-  if (is.null(k)) {
-    k <- 3
-  }
+
   # formatting the output properly
   output <-
     base::trimws(
